gitwrap::add

Function ignore_missing

pub fn ignore_missing() -> FnOptionArg
This option can only be used together with –dry-run. By using this option the user can check if any of the given files would be ignored, no matter if they are already present in the work tree or not. –ignore-missing