ignore_skip_worktree_bits

Function ignore_skip_worktree_bits 

pub fn ignore_skip_worktree_bits() -> FnOptionArg
In sparse checkout mode, git checkout – would update only entries matched by and sparse patterns in $GIT_DIR/info/sparse-checkout. This option ignores the sparse patterns and adds back any files in . –ignore-skip-worktree-bits