pub fn exclude(pattern_arg: &str) -> FnOptionArgExpand description
Use the given exclude pattern in addition to the standard ignore rules.
-e=
pub fn exclude(pattern_arg: &str) -> FnOptionArgUse the given exclude pattern in addition to the standard ignore rules.
-e=