branch

Function branch 

pub fn branch(name_arg: &str) -> FnOptionArg
Instead of pointing the newly created HEAD to the branch pointed to by the cloned repository’s HEAD, point to branch instead. In a non-bare repository, this is the branch that will be checked out. –branch can also take tags and detaches the HEAD at that commit in the resulting repository. –branch , -b