upload_pack

Function upload_pack 

pub fn upload_pack(upload_pack_arg: &str) -> FnOptionArg
When given, and the repository to clone from is accessed via ssh, this specifies a non-default path for the command run on the other end. –upload-pack , -u