pub fn all() -> FnOptionArgExpand description
Tell the command to automatically stage files that have been modified and deleted, but new files you have not told Git about are not affected. -a, –all
pub fn all() -> FnOptionArgTell the command to automatically stage files that have been modified and deleted, but new files you have not told Git about are not affected. -a, –all