pub fn patch() -> FnOptionArgExpand description
Use the interactive patch selection interface to chose which changes to commit. See git-add(1) for details. -p, –patch
pub fn patch() -> FnOptionArgUse the interactive patch selection interface to chose which changes to commit. See git-add(1) for details. -p, –patch