Adds a new line to the option without altering any existing values. This is the same as providing ^$ as the value_regex in –replace-all.
–add
Similar to –file but use the given blob instead of a file. E.g. you can use master:.gitmodules to read values from the file .gitmodules in the master branch. See ‘SPECIFYING REVISIONS’ section in gitrevisions(7) for a more complete list of ways to spell blob names.
–blob
git config will ensure that the output is ‘true’ or ‘false’
–bool
git config will ensure that the output matches the format of either –bool or –int, as described above.
–bool-or-int
Opens an editor to modify the specified config file; either –system, –global, or repository (default).
-e, –edit
Adds a configuration entry
Use the given config file instead of the one specified by GIT_CONFIG.
-f , –file
Get the value for a given key (optionally filtered by a regex matching the value). Returns error code 1 if the key was not found and the last value if multiple key values were found.
–get
Like get, but returns all values for a multi-valued key.
get-all
Find the color configured for name (e.g. color.diff.new) and output it as the ANSI color escape sequence to the standard output. The optional default parameter is used instead, if there is no color configured for name.
–get-color name [default]
Find the color setting for name (e.g. color.diff) and output “true” or “false”. stdout-is-tty should be either “true” or “false”, and is taken into account when configuration says “auto”. If stdout-is-tty is missing, then checks the standard output of the command itself, and exits with status 0 if color is to be used, or exits with status 1 otherwise. When the color setting for name is undefined, the command uses color.ui as fallback.
–get-colorbool name [stdout-is-tty]
When given a two-part name section.key, the value for section..key whose part matches the best to the given URL is returned (if no such key exists, the value for section.key is used as a fallback). When given just the section as name, do so for all the keys in the section and list them. Returns error code 1 if no value is found.
–get-urlmatch name URL
For writing options: write to global ~/.gitconfig file rather than the repository .git/config, write to $XDG_CONFIG_HOME/git/config file if this file exists and the ~/.gitconfig file doesn’t.
–global
git config will ensure that the output is a simple decimal number. An optional value suffix of k, m, or g in the config file will cause the value to be multiplied by 1024, 1048576, or 1073741824 prior to output.
–int
List all variables set in config file, along with their values.
-l, –list
For writing options: write to the repository .git/config file. This is the default behavior.
–local
Output only the names of config variables for –list or –get-regexp.
–name-only
For all options that output values and/or keys, always end values with the null character (instead of a newline). Use newline instead as a delimiter between key and value. This allows for secure parsing of the output without getting confused e.g. by values that contain line breaks.
-z, –null
git-config will expand leading ~ to the value of $HOME, and ~user to the home directory for the specified user. This option has no effect when setting the value (but you can use git config bla ~/ from the command line to let your shell do the expansion).
–path
Remove the given section from the configuration file.
–remove-section
Rename the given section to a new name.
–rename-section
Default behavior is to replace at most one line. This replaces all lines matching the key (and optionally the value_regex).
–replace-all
Augment the output of all queried config options with the origin type (file, standard input, blob, command line) and the actual origin (config file path, ref, or blob id if applicable).
–show-origin
For writing options: write to system-wide $(prefix)/etc/gitconfig rather than the repository .git/config.
–system
Remove the line matching the key from config file.
–unset
Remove all lines matching the key from config file.
–unset-all