show_origin

Function show_origin 

pub fn show_origin() -> FnOptionArg
Augment the output of all queried config options with the origin type (file, standard input, blob, command line) and the actual origin (config file path, ref, or blob id if applicable). –show-origin