recurse_submodules

Function recurse_submodules 

pub fn recurse_submodules(value: &str) -> FnOptionArg
This option controls if and under what conditions new commits of populated submodules should be fetched too. –recurse-submodules[=yes|on-demand|no]