pub fn shallow_since(date_arg: &str) -> FnOptionArgExpand description
Deepen or shorten the history of a shallow repository to include all reachable commits after
pub fn shallow_since(date_arg: &str) -> FnOptionArgDeepen or shorten the history of a shallow repository to include all reachable commits after