pub fn man_path() -> FnOptionArgExpand description
Print the manpath (see man(1)) for the man pages for this version of Git and exit. –man-path
pub fn man_path() -> FnOptionArgPrint the manpath (see man(1)) for the man pages for this version of Git and exit. –man-path