pub fn ff_only() -> FnOptionArgExpand description
Refuse to merge and exit with a non-zero status unless the current HEAD is already up-to-date or the merge can be resolved as a fast-forward. –ff-only
pub fn ff_only() -> FnOptionArgRefuse to merge and exit with a non-zero status unless the current HEAD is already up-to-date or the merge can be resolved as a fast-forward. –ff-only