no_commit

Function no_commit 

pub fn no_commit() -> FnOptionArg
With –no-commit perform the merge but pretend the merge failed and do not autocommit, to give the user a chance to inspect and further tweak the merge result before committing. –commit, –no-commit