pub fn edit() -> CommandOption<'static>Expand description
The message taken from file with -F, command line with -m, and from commit object with -C are usually used as the commit log message unmodified. This option lets you further edit the message taken from these sources. -e, –edit