gitwrap::options::commit

Function gpg_sign

pub fn gpg_sign(keyid_arg: &str) -> CommandOption<'_>
GPG-sign commits. The keyid argument is optional and defaults to the committer identity; if specified, it must be stuck to the option without a space. -S[], –gpg-sign[=]