pub fn reuse_message(commit_arg: &str) -> CommandOption<'_>Expand description
Take an existing commit object, and reuse the log message and the authorship information (including the timestamp) when creating the commit.
-C
pub fn reuse_message(commit_arg: &str) -> CommandOption<'_>Take an existing commit object, and reuse the log message and the authorship information (including the timestamp) when creating the commit.
-C