pub fn bool_or_int() -> CommandOption<'static>Expand description
git config will ensure that the output matches the format of either –bool or –int, as described above. –bool-or-int
pub fn bool_or_int() -> CommandOption<'static>git config will ensure that the output matches the format of either –bool or –int, as described above. –bool-or-int