gitwrap::options::ls_files

Function sparse

pub fn sparse() -> CommandOption<'static>
If the index is sparse, show the sparse directories without expanding to the contained files. Sparse directories will be shown with a trailing slash, such as “x/” for a sparse directory •“x•”. –sparse