gitwrap::options::merge

Function log

pub fn log(n_arg: &str) -> CommandOption<'_>
In addition to branch names, populate the log message with one-line descriptions from at most actual commits that are being merged. See also git-fmt-merge-msg(1). With –no-log do not list one-line descriptions from the actual commits being merged. –log[=], –no-log