gitwrap::options::pull

Function depth

pub fn depth(depth_arg: &str) -> CommandOption<'_>
Limit fetching to the specified number of commits from the tip of each remote branch history. If fetching to a shallow repository created by git clone with –depth= option (see git-clone(1)), deepen or shorten the history to the specified number of commits. Tags for the deepened commits are not fetched. –depth=