gitwrap::options::pull

Function no_ff

pub fn no_ff() -> CommandOption<'static>
Create a merge commit even when the merge resolves as a fast-forward. This is the default behaviour when merging an annotated (and possibly signed) tag. –no-ff