pub fn no_recurse_submodules(value: &str) -> CommandOption<'_>Expand description
This option controls if new commits of all populated submodules should be fetched too. –no-recurse-submodules[=yes|on-demand|no]
pub fn no_recurse_submodules(value: &str) -> CommandOption<'_>This option controls if new commits of all populated submodules should be fetched too. –no-recurse-submodules[=yes|on-demand|no]