gitwrap::options::pull

Function no_verify_signatures

pub fn no_verify_signatures() -> CommandOption<'static>
Verify that the tip commit of the side branch being merged is signed with a valid key, i.e. a key that has a valid uid: in the default trust model, this means the signing key has been signed by a trusted key. –no-verify-signatures