gitwrap::options::push

Function force

pub fn force() -> CommandOption<'static>
Usually, the command refuses to update a remote ref that is not an ancestor of the local ref used to overwrite it. Also, when –force-with-lease option is used, the command refuses to update a remote ref whose current value does not match what is expected. -f, –force