pub fn tags() -> CommandOption<'static>Expand description
All refs under refs/tags are pushed, in addition to refspecs explicitly listed on the command line. –tags
pub fn tags() -> CommandOption<'static>All refs under refs/tags are pushed, in addition to refspecs explicitly listed on the command line. –tags