pub fn verify() -> CommandOption<'static>Expand description
Toggle the pre-push hook (see githooks(5)). The default is –verify, giving the hook a chance to prevent the push. With –no-verify, the hook is bypassed completely. –verify
pub fn verify() -> CommandOption<'static>Toggle the pre-push hook (see githooks(5)). The default is –verify, giving the hook a chance to prevent the push. With –no-verify, the hook is bypassed completely. –verify