gitwrap::options::rebase

Function abort

pub fn abort() -> CommandOption<'static>
Abort the rebase operation and reset HEAD to the original branch. If was provided when the rebase operation was started, then HEAD will be reset to . Otherwise HEAD will be reset to where it was when the rebase operation was started. –abort