pub fn continue_rebase() -> CommandOption<'static>Expand description
Restart the rebasing process after having resolved a merge conflict. –continue
pub fn continue_rebase() -> CommandOption<'static>Restart the rebasing process after having resolved a merge conflict. –continue