gitwrap::options::reset

Function mixed

pub fn mixed() -> CommandOption<'static>
Resets the index but not the working tree (i.e., the changed files are preserved but not marked for commit) and reports what has not been updated. This is the default action. If -N is specified, removed paths are marked as intent-to-add (see git-add(1)). –mixed