gitwrap::options::revparse

Function local_env_vars

pub fn local_env_vars() -> CommandOption<'static>
List the GIT_* environment variables that are local to the repository (e.g. GIT_DIR or GIT_WORK_TREE, but not GIT_EDITOR). Only the names of the variables are listed, not their value, even if they are set. –local-env-vars