gitwrap::options::tag

Function edit

pub fn edit() -> CommandOption<'static>
The message taken from file with -F and command line with -m are usually used as the tag message unmodified. This option lets you further edit the message taken from these sources. -e, –edit