update_head_ok

Function update_head_ok 

pub fn update_head_ok() -> FnOptionArg
By default git fetch refuses to update the head which corresponds to the current branch. This flag disables the check. This is purely for the internal use for git pull to communicate with git fetch, and unless you are implementing your own Porcelain you are not supposed to use it. -u, –update-head-ok