gitwrap::pull

Function upload_pack

pub fn upload_pack(upload_pack_arg: &str) -> FnOptionArg
When given, and the repository to fetch from is handled by git fetch-pack, –exec= is passed to the command to specify non-default path for the command run on the other end. –upload-pack