pub fn continue_rebase() -> FnOptionArgExpand description
Restart the rebasing process after having resolved a merge conflict. –continue
pub fn continue_rebase() -> FnOptionArgRestart the rebasing process after having resolved a merge conflict. –continue