gitwrap::rebase

Function ensure_context

pub fn ensure_context(n_arg: &str) -> FnOptionArg
Ensure at least lines of surrounding context match before and after each change. When fewer lines of surrounding context exist they all must match. By default no context is ever ignored. Implies –apply. -C