pub fn no_autosquash() -> FnOptionArgExpand description
When the commit log message begins with “squash! …” or “fixup! …” or “amend! …”, and there is already a commit in the todo list that matches the same …, automatically modify the todo list of rebase -i, so that the commit marked for squashing comes right after the commit to be modified, and change the action of the moved commit from pick to squash or fixup or fixup -C respectively. A commit matches the … if the commit subject matches, or if the … refers to the commit’s hash. As a fall-back, partial matches of the commit subject work, too. The recommended way to create fixup/amend/squash commits is by using the –fixup, –fixup=amend: or –fixup=reword: and –squash options respectively of git-commit(1). If the –autosquash option is enabled by default using the configuration variable rebase.autoSquash, this option can be used to override and disable this setting. –autosquash, –no-autosquash