no_ff

Function no_ff 

pub fn no_ff() -> FnOptionArg
Individually replay all rebased commits instead of fast-forwarding over the unchanged ones. This ensures that the entire history of the rebased branch is composed of new commits. You may find this helpful after reverting a topic branch merge, as this option recreates the topic branch with fresh commits so it can be remerged successfully without needing to “revert the reversion” (see the revert-a-faulty-merge How-To[1] for details). –no-ff, –force-rebase, -f