gitwrap::rebase

Function onto

pub fn onto(newbase_arg: &str) -> FnOptionArg
Starting point at which to create the new commits. If the –onto option is not specified, the starting point is . May be any valid commit, and not just an existing branch name. As a special case, you may use “A…B” as a shortcut for the merge base of A and B if there is exactly one merge base. You can leave out at most one of A and B, in which case it defaults to HEAD. –onto