pub fn signoff() -> FnOptionArgExpand description
Add a Signed-off-by trailer to all the rebased commits. Note that if –interactive is given then only commits marked to be picked, edited or reworded will have the trailer added. –signoff
pub fn signoff() -> FnOptionArgAdd a Signed-off-by trailer to all the rebased commits. Note that if –interactive is given then only commits marked to be picked, edited or reworded will have the trailer added. –signoff