strategy

Function strategy 

pub fn strategy(strategy_arg: &str) -> FnOptionArg
Use the given merge strategy, instead of the default ort. This implies –merge. Because git rebase replays each commit from the working branch on top of the branch using the given strategy, using the ours strategy simply empties all patches from the , which makes little sense. -s , –strategy=