pub fn abbrev_ref(value: &str) -> FnOptionArgExpand description
A non-ambiguous short name of the objects name. The option core.warnAmbiguousRefs is used to select the strict abbreviation mode. –abbrev-ref[=(strict|loose)]
pub fn abbrev_ref(value: &str) -> FnOptionArgA non-ambiguous short name of the objects name. The option core.warnAmbiguousRefs is used to select the strict abbreviation mode. –abbrev-ref[=(strict|loose)]