gitwrap::rev_parse

Function show_prefix

pub fn show_prefix() -> FnOptionArg
When the command is invoked from a subdirectory, show the path of the current directory relative to the top-level directory. –show-prefix