pub fn stop_at_non_option() -> FnOptionArgExpand description
Only meaningful in –parseopt mode. Lets the option parser stop at the first non-option argument. This can be used to parse sub-commands that take options themselves. –stop-at-non-option
pub fn stop_at_non_option() -> FnOptionArgOnly meaningful in –parseopt mode. Lets the option parser stop at the first non-option argument. This can be used to parse sub-commands that take options themselves. –stop-at-non-option