gitwrap

Module tag

Functions

  • Make an unsigned, annotated tag object. -a, –annotate
  • This option sets how the tag message is cleaned up. The can be one of verbatim, whitespace and strip. The strip mode is default. The verbatim mode does not change message at all, whitespace removes just leading/trailing whitespace lines and strip removes both whitespace and commentary. –cleanup=
  • Respect any colors specified in the –format option. The field must be one of always, never, or auto (if is absent, behave as if always was given). –color[=]
  • Display tag listing in columns. See configuration variable column.tag for option syntax.–column and –no-column without options are equivalent to always and never respectively.
  • Only list tags which contain the specified commit (HEAD if not specified). Implies –list. –contains []
  • Create a reflog for the tag. To globally enable reflogs for tags, see core.logAllRefUpdates in git-config(1). The negated form –no-create-reflog only overrides an earlier –create-reflog, but currently does not negate the setting of core.logAllRefUpdates. –create-reflog
  • The message taken from file with -F and command line with -m are usually used as the tag message unmodified. This option lets you further edit the message taken from these sources. -e, –edit
  • Take the tag message from the given file. Use - to read the message from the standard input. Implies -a if none of -a, -s, or -u is given. -F , –file=
  • Replace an existing tag with the given name (instead of failing). -f, –force
  • Sorting and filtering tags are case insensitive. -i, –ignore-case
  • List tags. With optional …, e.g. git tag –list ‘v-*’, list only the tags that match the pattern(s).
  • Make a GPG-signed tag, using the given key. -u , –local-user=
  • Only list tags whose commits are reachable from the specified commit (HEAD if not specified), incompatible with –no-merged. –merged []
  • Use the given tag message (instead of prompting). If multiple -m options are given, their values are concatenated as separate paragraphs. Implies -a if none of -a, -s, or -u is given. -m , –message=
  • specifies how many lines from the annotation, if any, are printed when using -l. Implies –list.
  • Display tag listing in columns. See configuration variable column.tag for option syntax.–column and –no-column without options are equivalent to always and never respectively.
  • Only list tags which don’t contain the specified commit (HEAD if not specified). Implies –list. –no-contains []
  • Only list tags whose commits are not reachable from the specified commit (HEAD if not specified), incompatible with –merged. –no-merged []
  • Only list tags of the given object (HEAD if not specified). Implies –list. –points-at
  • Make a GPG-signed tag, using the default e-mail address’s key. -s, –sign
  • Sort based on the key given. Prefix - to sort in descending order of the value. You may use the –sort= option multiple times, in which case the last key becomes the primary key. Also supports “version:refname” or “v:refname” (tag names are treated as versions). The “version:refname” sort order can also be affected by the “versionsort.suffix” configuration variable. The keys supported are the same as those in git for-each-ref. Sort order defaults to the value configured for the tag.sort variable if it exists, or lexicographic order otherwise. See git-config(1). –sort=
  • Verify the GPG signature of the given tag names. -v, –verify