pub fn message(msg_arg: &str) -> FnOptionArgExpand description
Use the given tag message (instead of prompting).
If multiple -m options are given, their values are concatenated as separate paragraphs.
Implies -a if none of -a, -s, or -u
pub fn message(msg_arg: &str) -> FnOptionArgUse the given tag message (instead of prompting).
If multiple -m options are given, their values are concatenated as separate paragraphs.
Implies -a if none of -a, -s, or -u