WrapCommand

Struct WrapCommand 

pub struct WrapCommand { /* private fields */ }
A git command wrapper and manager

Implementations

Source

impl WrapCommand

pub fn new(cmd: &str) -> Self

Creates a new git [cmd] command.

pub fn current_dir(&self, dir: &str) -> Self

Set this WrapCommand current_dir to [dir] When [current_dir] is set, the command working directory is set to it at run.

pub fn add_option(&self, arg: FnOptionArg) -> Self

Includes a new git command option

pub fn add_options<I>(&self, args: I) -> Self
where I: IntoIterator<Item = FnOptionArg>,

Includes several new git command options at once

pub fn run(&self) -> Result<String, WrapError>

Executes the git command as a child process, waiting for it to finish and collecting all of its output. By default, stdout and stderr are captured (and used to provide the result string).

pub fn dry_run(&self) -> Result<String, WrapError>

Dry-runs the git command returning the full command specification provided