Update the index not only where the working tree has a file matching but also where the index already has an entry.
This adds, modifies, and removes index entries to match the working tree.
If no is given when -A option is used, all files in the entire working tree are updated (old versions of Git used to limit the update to the current directory and its subdirectories).
-A, –all, –no-ignore-removal