Update the index just where it already has an entry matching .
This removes as well as modifies index entries to match the working tree, but adds no new files.
If no is given when -u option is used, all tracked files in the entire working tree are updated (old versions of Git used to limit the update to the current directory and its subdirectories).
-u, –update