Don’t actually remove anything, just show what would be done. Configuration variable clean.requireForce is ignored, as nothing will be deleted anyway
-n, –dry-run
Use the given exclude pattern in addition to the standard ignore rules (see gitignore[5])
-e=
, –exclude=If the Git configuration variable clean.requireForce is not set to false, git clean will refuse to delete files or directories unless given -f. Git will refuse to modify untracked nested git repositories (directories with a .git subdirectory) unless a second -f is given
-f, –force
Remove only files ignored by Git. This may be useful to rebuild everything from scratch, but keep manually created files
-X
Show what would be done and clean files interactively. See “Interactive mode” for details. Configuration variable clean.requireForce is ignored, as this mode gives its own safety protection by going interactive
-i, –interactive
Don’t use the standard ignore rules (see gitignore[5]), but still use the ignore rules given with -e options from the command line. This allows removing all untracked files, including build products. This can be used (possibly in conjunction with git restore or git reset) to create a pristine working directory to test a clean build
-x
If any optional
… arguments are given, only those paths that match the pathspec are affected
– Be quiet, only report errors, but not the files that are successfully removed
-q, –quiet
Normally, when no
is specified, git clean will not recurse into untracked directories to avoid removing too much. Specify -d to have it recurse into such directories as well. If a is specified, -d is irrelevant; all untracked files matching the specified paths (with exceptions for nested git directories mentioned under –force) will be removed
-d