pub fn branch(name_arg: &str) -> FnOptionArgExpand description
Instead of pointing the newly created HEAD to the branch pointed to by the cloned repository’s HEAD, point to
pub fn branch(name_arg: &str) -> FnOptionArgInstead of pointing the newly created HEAD to the branch pointed to by the cloned repository’s HEAD, point to