pub fn config() -> WrapCommandExpand description
Get and set repository or global options. You can query/set/replace/unset options with this command. The name is actually the section and the key separated by a dot, and the value will be escaped. Git doc