pub fn recurse_submodules(value: &str) -> CommandOption<'_>Expand description
This option controls if and under what conditions new commits of populated submodules should be fetched too. –recurse-submodules[=yes|on-demand|no]
pub fn recurse_submodules(value: &str) -> CommandOption<'_>This option controls if and under what conditions new commits of populated submodules should be fetched too. –recurse-submodules[=yes|on-demand|no]