Manipulate the notes tree in .
This overrides GIT_NOTES_REF and the “core.notesRef” configuration.
The ref specifies the full refname when it begins with refs/notes/;
when it begins with notes/, refs/ and otherwise refs/notes/ is prefixed to form a full name of the ref.
–ref