pub fn shared() -> CommandOption<'static>Expand description
When the repository to clone is on the local machine, instead of using hard links, automatically setup .git/objects/info/alternates to share the objects with the source repository. The resulting repository starts out without any object of its own. –shared, -s