pub fn separate_git_dir(git_dir_arg: &str) -> CommandOption<'_>Expand description
Instead of initializing the repository as a directory to either $GIT_DIR or ./.git/, create a text file there containing the path to the actual repository.
This file acts as filesystem-agnostic Git symbolic link to the repository.
–separate-git-dir=