pub fn no_progress() -> CommandOption<'static>Expand description
Turn progress on/off explicitly. If neither is specified, progress is shown if standard error is connected to a terminal. Note that not all merge strategies may support progress reporting. –progress, –no-progress