pub fn depth(depth_arg: &str) -> CommandOption<'_>Expand description
Limit fetching to the specified number of commits from the tip of each remote branch history.
If fetching to a shallow repository created by git clone with –depth=
pub fn depth(depth_arg: &str) -> CommandOption<'_>Limit fetching to the specified number of commits from the tip of each remote branch history.
If fetching to a shallow repository created by git clone with –depth=