pub fn no_atomic() -> FnOptionArgExpand description
Use an atomic transaction on the remote side if available. Either all refs are updated, or on error, no refs are updated. If the server does not support atomic pushes the push will fail. –no-atomic