pub fn committer_date_is_author_date() -> FnOptionArgExpand description
Instead of using the current time as the committer date, use the author date of the commit being rebased as the committer date. This option implies –force-rebase. –committer-date-is-author-date