pub fn strategy(strategy_arg: &str) -> FnOptionArgExpand description
Use the given merge strategy, instead of the default ort.
This implies –merge.
Because git rebase replays each commit from the working branch on top of the
pub fn strategy(strategy_arg: &str) -> FnOptionArgUse the given merge strategy, instead of the default ort.
This implies –merge.
Because git rebase replays each commit from the working branch on top of the