pub fn show_prefix() -> FnOptionArgExpand description
When the command is invoked from a subdirectory, show the path of the current directory relative to the top-level directory. –show-prefix
pub fn show_prefix() -> FnOptionArgWhen the command is invoked from a subdirectory, show the path of the current directory relative to the top-level directory. –show-prefix