This option sets how the tag message is cleaned up. The can be one of verbatim, whitespace and strip. The strip mode is default. The verbatim mode does not change message at all, whitespace
removes just leading/trailing whitespace lines and strip removes both whitespace and commentary.
–cleanup=
Respect any colors specified in the –format option. The field must be one of always, never, or auto (if is absent, behave as if always was given).
–color[=]
Display tag listing in columns. See configuration variable column.tag for option syntax.–column and –no-column without options are equivalent to always and never respectively.
Create a reflog for the tag. To globally enable reflogs for tags, see core.logAllRefUpdates in git-config(1). The negated form –no-create-reflog only overrides an earlier –create-reflog, but
currently does not negate the setting of core.logAllRefUpdates.
–create-reflog
The message taken from file with -F and command line with -m are usually used as the tag message unmodified.
This option lets you further edit the message taken from these sources.
-e, –edit
Use the given tag message (instead of prompting).
If multiple -m options are given, their values are concatenated as separate paragraphs. Implies -a if none of -a, -s, or -u is given.
-m , –message=
Display tag listing in columns. See configuration variable column.tag for option syntax.–column and –no-column without options are equivalent to always and never respectively.
Sort based on the key given. Prefix - to sort in descending order of the value. You may use the –sort= option multiple times, in which case the last key becomes the primary key. Also
supports “version:refname” or “v:refname” (tag names are treated as versions). The “version:refname” sort order can also be affected by the “versionsort.suffix” configuration variable. The keys
supported are the same as those in git for-each-ref. Sort order defaults to the value configured for the tag.sort variable if it exists, or lexicographic order otherwise. See git-config(1).
–sort=